@@ -49,14 +49,14 @@ def sdist_expected_correct_file_structure():
         'src/cookiecutter_python/{{ cookiecutter.project_slug }}/.readthedocs.yml',
         'src/cookiecutter_python/{{ cookiecutter.project_slug }}/Dockerfile',
         'src/cookiecutter_python/{{ cookiecutter.project_slug }}/MANIFEST.in',
-        'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.docs_builder == "mkdocs" %}docs{% else %}PyGen_TO_DELETE{% endif %}/assets/docker_off.png',
-        'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.docs_builder == "mkdocs" %}docs{% else %}PyGen_TO_DELETE{% endif %}/build-process_DAG.md',
-        'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.docs_builder == "mkdocs" %}docs{% else %}PyGen_TO_DELETE{% endif %}/cicd.md',
-        'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.docs_builder == "mkdocs" %}docs{% else %}PyGen_TO_DELETE{% endif %}/cicd_mermaid.md',
-        'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.docs_builder == "mkdocs" %}docs{% else %}PyGen_TO_DELETE{% endif %}/dev_guides/docker.md',
-        'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.docs_builder == "mkdocs" %}docs{% else %}PyGen_TO_DELETE{% endif %}/dev_guides/index.md',
-        'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.docs_builder == "mkdocs" %}docs{% else %}PyGen_TO_DELETE{% endif %}/dockerfile_mermaid.md',
+        # MKDOCS
         'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.docs_builder == "mkdocs" %}docs{% else %}PyGen_TO_DELETE{% endif %}/index.md',
+        'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.docs_builder == "mkdocs" %}docs{% else %}PyGen_TO_DELETE{% endif %}/topics/arch.md',
+        'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.docs_builder == "mkdocs" %}docs{% else %}PyGen_TO_DELETE{% endif %}/topics/development/build_process_DAG.md',
+        'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.docs_builder == "mkdocs" %}docs{% else %}PyGen_TO_DELETE{% endif %}/topics/development/cicd.md',
+        'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.docs_builder == "mkdocs" %}docs{% else %}PyGen_TO_DELETE{% endif %}/topics/development/cicd_mermaid.md',
+        'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.docs_builder == "mkdocs" %}docs{% else %}PyGen_TO_DELETE{% endif %}/topics/development/dockerfile_mermaid.md',
+        'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.docs_builder == "mkdocs" %}docs{% else %}PyGen_TO_DELETE{% endif %}/topics/development/index.md',
         'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.docs_builder == "mkdocs" %}docs{% else %}PyGen_TO_DELETE{% endif %}/tags.md',
         'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.docs_builder == "sphinx" %}docs{% else %}PyGen_TO_DELETE{% endif %}/Makefile',
         'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.docs_builder == "sphinx" %}docs{% else %}PyGen_TO_DELETE{% endif %}/conf.py',
@@ -170,14 +170,14 @@ def sdist_expected_correct_file_structure():
         'tests/data/snapshots/biskotaki-gold-standard/CHANGELOG.rst',
         'tests/data/snapshots/biskotaki-gold-standard/CONTRIBUTING.md',
         'tests/data/snapshots/biskotaki-gold-standard/Dockerfile',
-        'tests/data/snapshots/biskotaki-gold-standard/docs/assets/docker_off.png',
-        'tests/data/snapshots/biskotaki-gold-standard/docs/build-process_DAG.md',
-        'tests/data/snapshots/biskotaki-gold-standard/docs/cicd.md',
-        'tests/data/snapshots/biskotaki-gold-standard/docs/cicd_mermaid.md',
-        'tests/data/snapshots/biskotaki-gold-standard/docs/dev_guides/docker.md',
-        'tests/data/snapshots/biskotaki-gold-standard/docs/dev_guides/index.md',
-        'tests/data/snapshots/biskotaki-gold-standard/docs/dockerfile_mermaid.md',
+        # MKDOCS Docs dir
         'tests/data/snapshots/biskotaki-gold-standard/docs/index.md',
+        'tests/data/snapshots/biskotaki-gold-standard/docs/topics/arch.md',
+        'tests/data/snapshots/biskotaki-gold-standard/docs/topics/development/build_process_DAG.md',
+        'tests/data/snapshots/biskotaki-gold-standard/docs/topics/development/cicd.md',
+        'tests/data/snapshots/biskotaki-gold-standard/docs/topics/development/cicd_mermaid.md',
+        'tests/data/snapshots/biskotaki-gold-standard/docs/topics/development/dockerfile_mermaid.md',
+        'tests/data/snapshots/biskotaki-gold-standard/docs/topics/development/index.md',
         'tests/data/snapshots/biskotaki-gold-standard/docs/tags.md',
         'tests/data/snapshots/biskotaki-gold-standard/LICENSE',
         'tests/data/snapshots/biskotaki-gold-standard/mkdocs.yml',
